pecos.error\_models.noise\_impl.noise\_meas\_bitflip\_leakage
=============================================================

.. automodule:: pecos.error_models.noise_impl.noise_meas_bitflip_leakage







   .. rubric:: Functions

   .. autosummary::

      noise_meas_bitflip_leakage
